@@ -30,13 +30,13 @@ _max = 100
 EXCEED_NOTICE = f'您今天已经冲过{_max}次了，请明早5点后再来！'
 _nlmt = DailyNumberLimiter(_max)
 _flmt = FreqLimiter(3)
-__version__ = '0.3.3'
+__version__ = '0.3.3.1'
 dir_path = Path(__file__).parent
 template_path = dir_path / "template"
 
 bot = on_command("wws", block=False, aliases={"WWS"},priority=5)
-bot_listen = on_message(priority=5)
-bot_checkversion = on_command("wws 检查更新",priority=5)
+bot_listen = on_message(priority=5,block=False)
+bot_checkversion = on_command("wws 检查更新",priority=5,block=False)
 driver = get_driver()
 
 @bot.handle()
