@@ -31,24 +31,22 @@ headers = {
 ShipSlectState = namedtuple("ShipSlectState", ['state','SlectIndex','SelectList'])
 ShipSecletProcess = defaultdict(lambda: ShipSlectState(False, None, None))
 
-async def get_ShipInfo(qqid,info,bot):
+async def get_ShipInfo(server_type,qqid,info,bot):
     try:
         url,params = '',''
         if isinstance(info,List):
             for flag,i in enumerate(info):              #是否包含me或@，包含则调用平台接口
                 if str(i).lower() == 'me':
-                    url = 'https://api.wows.linxun.link/public/wows/account/v2/ship/info'
                     params = {
-                    "server": "QQ",
-                    "accountId": qqid,
+                    "server": server_type,
+                    "accountId": int(qqid),
                     }
                     info.remove(str(i))
                 match = re.search(r"CQ:at,qq=(\d+)",i)
                 if match:
-                    url = 'https://api.wows.linxun.link/public/wows/account/v2/ship/info'
                     params = {
-                    "server": "QQ",
-                    "accountId": match.group(1),
+                    "server": server_type,
+                    "accountId": int(match.group(1)),
                     }
                     info[flag] = str(i).replace(f"[{match.group(0)}]",'')
                     if not info[flag]:
@@ -58,17 +56,14 @@ async def get_ShipInfo(qqid,info,bot):
                 param_server,info = await match_keywords(info,servers)
                 if param_server:
                     param_accountid = await get_AccountIdByName(param_server,str(info[0]))      #剩余列表第一个是否为游戏名
-                    if param_accountid and param_accountid != 404:
+                    if isinstance(param_accountid,int):
                         info.remove(info[0])
-                        url = 'https://api.wows.linxun.link/public/wows/account/v2/ship/info'
                         params = {
                         "server": param_server,
                         "accountId": param_accountid,
                         }
-                    elif param_accountid == 404:
-                        return '无法查询该游戏昵称Orz，请检查昵称是否存在'
                     else:
-                        return '发生了错误，有可能是网络波动，请稍后再试'
+                        return f"{param_accountid}"
                 else:
                     return '服务器参数似乎输错了呢'
             elif params and len(info) == 1:
@@ -105,14 +100,17 @@ async def get_ShipInfo(qqid,info,bot):
                 return '找不到船'
         else:
             return '参数似乎出了问题呢'
+        url = 'https://api.wows.shinoaki.com/public/wows/account/v2/ship/info'
         logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
         ranking = await get_MyShipRank_yuyuko(params)
         async with httpx.AsyncClient(headers=headers) as client:
-            resp = await client.get(url, params=params, timeout=20)
+            resp = await client.get(url, params=params, timeout=None)
             result = resp.json()
             logger.info(f"本次请求返回的状态码:{result['code']}")
             logger.info(f"本次请求服务器计算时间:{result['queryTime']}")
         if result['code'] == 200 and result['data']:
+            if not result['data']['shipInfo']['battles'] and not result['data']['rankSolo']['battles']:
+                return '查询不到战绩数据'
             template = env.get_template("wws-ship.html")
             template_data = await set_shipparams(result['data'])
             template_data['shipRank'] = ranking
@@ -138,9 +136,9 @@ async def get_ShipInfo(qqid,info,bot):
     
 async def get_MyShipRank_yuyuko(params):
     try:
-        url = 'https://api.wows.linxun.link/upload/numbers/data/upload/user/ship/rank'
+        url = 'https://api.wows.shinoaki.com/upload/numbers/data/upload/user/ship/rank'
         async with httpx.AsyncClient(headers=headers) as client:
-            resp = await client.get(url, params=params, timeout=20)
+            resp = await client.get(url, params=params, timeout=None)
             result = resp.json()
             if result['code'] == 200 and result['data']:
                 if result['data']['ranking']:
@@ -162,14 +160,14 @@ async def get_MyShipRank_Numbers(url,server):
     try:
         data = None
         async with httpx.AsyncClient() as client:
-            resp = await client.get(url, timeout=20)
+            resp = await client.get(url, timeout=None)
             if resp.content:
                 result = resp.json()
                 page_url = str(result['url']).replace("\\","")
                 nickname = str(result['nickname'])
                 my_rank_url = f"{number_url_homes[server]}{page_url}"
                 async with httpx.AsyncClient() as client:
-                    resp = await client.get(my_rank_url, timeout=20)
+                    resp = await client.get(my_rank_url, timeout=None)
                     soup = BeautifulSoup(resp.content, 'html.parser')
                     data = soup.select_one(f'tr[data-nickname="{nickname}"]').select_one('td').string
         if data and data.isdigit():
@@ -183,14 +181,14 @@ async def get_MyShipRank_Numbers(url,server):
 async def post_MyShipRank_yuyuko(accountId,ranking,serverId,shipId):
     try:
         async with httpx.AsyncClient(headers=headers) as client:
-            url = 'https://api.wows.linxun.link/upload/numbers/data/upload/user/ship/rank'
+            url = 'https://api.wows.shinoaki.com/upload/numbers/data/upload/user/ship/rank'
             post_data = {
                 "accountId": int(accountId),
                 "ranking": int(ranking),
                 "serverId": serverId,
                 "shipId":int(shipId)
             }
-            resp = await client.post(url, json = post_data, timeout=20)
+            resp = await client.post(url, json = post_data, timeout=None)
             result = resp.json()
             return
     except Exception:
@@ -198,7 +196,7 @@ async def post_MyShipRank_yuyuko(accountId,ranking,serverId,shipId):
         return
     
     
-async def get_ShipInfoRecent(qqid,info,bot):
+async def get_ShipInfoRecent(server_type,qqid,info,bot):
     try:
         params,day = None,0
         if datetime.now().hour < 7:
@@ -213,19 +211,17 @@ async def get_ShipInfoRecent(qqid,info,bot):
                     info.remove(i)
             for flag,i in enumerate(info):              #是否包含me或@，包含则调用平台接口
                 if i == 'me':
-                    url = 'https://api.wows.linxun.link/api/wows/recent/v2/recent/info/ship'
                     params = {
-                    "server": "QQ",
-                    "accountId": qqid,
+                    "server": server_type,
+                    "accountId": int(qqid),
                     "day": day
                     }
                     info.remove("me")
                 match = re.search(r"CQ:at,qq=(\d+)",i)
                 if match:
-                    url = 'https://api.wows.linxun.link/api/wows/recent/v2/recent/info/ship'
                     params = {
-                    "server": "QQ",
-                    "accountId": match.group(1),
+                    "server": server_type,
+                    "accountId": int(match.group(1)),
                     "day": day
                     }
                     info[flag] = str(i).replace(f"[{match.group(0)}]",'')
@@ -236,18 +232,15 @@ async def get_ShipInfoRecent(qqid,info,bot):
                 param_server,info = await match_keywords(info,servers)
                 if param_server:
                     param_accountid = await get_AccountIdByName(param_server,str(info[0]))      #剩余列表第一个是否为游戏名
-                    if param_accountid and param_accountid != 404:
+                    if isinstance(param_accountid,int):
                         info.remove(info[0])
-                        url = 'https://api.wows.linxun.link/api/wows/recent/v2/recent/info/ship'
                         params = {
                         "server": param_server,
                         "accountId": param_accountid,
                         "day": day
                         }
-                    elif param_accountid == 404:
-                        return '无法查询该游戏昵称Orz，请检查昵称是否存在'
                     else:
-                        return '发生了错误，有可能是网络波动，请稍后再试'
+                        return f"{param_accountid}"
                 else:
                     return '服务器参数似乎输错了呢'
             elif params and len(info) == 1:
@@ -284,9 +277,10 @@ async def get_ShipInfoRecent(qqid,info,bot):
                 return '找不到船'
         else:
             return '参数似乎出了问题呢'
-        logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{params}")
+        url = 'https://api.wows.shinoaki.com/api/wows/recent/v2/recent/info/ship'
+        logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
         async with httpx.AsyncClient(headers=headers) as client:
-            resp = await client.get(url, params=params, timeout=20)
+            resp = await client.get(url, params=params, timeout=None)
             result = resp.json()
         if result['code'] == 200 and result['data']:
             template = env.get_template("wws-ship-recent.html")
